@@ -1,8 +1,9 @@
 #!/bin/sh
 
-for f in clamav freshclam; do
+for f in clamd freshclam; do
   if [ ! -e /etc/$f.conf ]; then mv /etc/$f.conf-dist /etc/$f.conf; fi
 done
 
 # update the database (/usr/share/clamav/)
-/usr/bin/freshclam
+# no: /etc/freshclam.conf needs now a database country specific mirror entry
+# /usr/bin/freshclam
